@@ -50,7 +50,7 @@ pyg_type_wrapper_repr(PyGTypeWrapper *self)
     const gchar *name = g_type_name(self->type);
 
     g_snprintf(buf, sizeof(buf), "<GType %s (%lu)>",
-	       name?name:"invalid", self->type);
+	       name?name:"invalid", (unsigned long int) self->type);
     return PyString_FromString(buf);
 }
 
@@ -628,6 +628,8 @@ pyg_value_array_from_pyobject(GValue *value,
 
 	if (pspec && pspec->element_spec)
 	    type = G_PARAM_SPEC_VALUE_TYPE(pspec->element_spec);
+	else if (item == Py_None)
+	    type = G_TYPE_POINTER; /* store None as NULL */
 	else {
 	    type = pyg_type_from_object((PyObject *) item->ob_type);
 	    if (! type) {
@@ -847,12 +849,26 @@ pyg_value_from_pyobject(GValue *value, PyObject *obj)
 
 	if (obj == Py_None)
 	    g_value_set_boxed(value, NULL);
-	if (G_VALUE_HOLDS(value, PY_TYPE_OBJECT))
+	else if (G_VALUE_HOLDS(value, PY_TYPE_OBJECT))
 	    g_value_set_boxed(value, obj);
 	else if (PyObject_TypeCheck(obj, &PyGBoxed_Type) &&
 		   G_VALUE_HOLDS(value, ((PyGBoxed *)obj)->gtype))
 	    g_value_set_boxed(value, pyg_boxed_get(obj, gpointer));
-	else if (PySequence_Check(obj) &&
+        else if (G_VALUE_HOLDS(value, G_TYPE_VALUE)) {
+            GType type;
+            GValue *n_value; 
+            
+            type = pyg_type_from_object((PyObject *)obj->ob_type);
+            if (G_UNLIKELY (! type)) {
+                PyErr_Clear();
+                return -1;
+            }
+            n_value = g_new0 (GValue, 1);
+            g_value_init (n_value, type);
+            g_value_take_boxed (value, n_value);
+            return pyg_value_from_pyobject (n_value, obj);
+        }
+        else if (PySequence_Check(obj) &&
 		   G_VALUE_HOLDS(value, G_TYPE_VALUE_ARRAY))
 	    return pyg_value_array_from_pyobject(value, obj, NULL);
 	else if (PyString_Check(obj) &&
@@ -1006,7 +1022,10 @@ pyg_value_as_pyobject(const GValue *value, gboolean copy_boxed)
 		return Py_None;
 	    }
 	    return ret;
-	} else if (G_VALUE_HOLDS(value, G_TYPE_VALUE_ARRAY)) {
+        } else if (G_VALUE_HOLDS(value, G_TYPE_VALUE)) {
+            GValue *n_value = g_value_get_boxed (value);
+            return pyg_value_as_pyobject(n_value, copy_boxed);
+        } else if (G_VALUE_HOLDS(value, G_TYPE_VALUE_ARRAY)) {
 	    GValueArray *array = (GValueArray *) g_value_get_boxed(value);
 	    PyObject *ret = PyList_New(array->n_values);
 	    int i;
