@@ -3,6 +3,16 @@ import unittest
 from gobject import GType
 from common import gobject, testhelper
 
+def raiseGError():
+    err = gobject.GError
+    err.message = "Test conversion between exception and GError"
+    err.code = 1
+    err.domain = ""
+    raise err
+
+def test_raiseGError():
+    testhelper.test_gerror_exception(raiseGError)
+
 class GTypeTest(unittest.TestCase):
     def checkType(self, expected, *objects):
         # First, double check so we get back what we sent
@@ -54,6 +64,11 @@ class GTypeTest(unittest.TestCase):
     def testObject(self):
         self.checkType(gobject.TYPE_OBJECT, 'PyObject')
 
+    def testValue(self):
+        array = [1, "foo", True]
+        for i in array:
+            self.assertEqual(i, testhelper.test_value(i))
+            
     def testValueArray(self):
         array = [1, 2, 3, "foo", True]
         self.assertEqual(array, testhelper.test_value_array(array))
@@ -62,6 +77,9 @@ class GTypeTest(unittest.TestCase):
         array = [1, 2, 3, "foo", True, None]
         self.assertEqual(array, testhelper.test_value_array(array))
 
+    def testGError(self):
+        self.assertRaises(gobject.GError, test_raiseGError)
+
     # XXX: Flags, Enums
 
 class MyObject(gobject.GObject):
